import { JSONSchema7, JSONSchema7TypeName } from "json-schema";
import { DPMConfiguration } from "./PackageUtil";
export declare enum Protocol {
    Http = "HTTP",
    LocalFile = "LOCAL_FILE"
}
export interface RegistryReference {
    url: string;
    catalogSlug: string;
}
export interface ParserInfo {
    mimeType: string;
    configuration?: DPMConfiguration;
}
export interface Source {
    protocol: Protocol;
    configuration?: DPMConfiguration;
}
export interface ValueTypeStatistics {
    valueType: JSONSchema7TypeName | "date";
    recordCount?: number;
    stringMaxLength?: number;
    stringMinLength?: number;
    numberMaxValue?: number;
    numberMinValue?: number;
    dateMaxValue?: Date;
    dateMinValue?: Date;
    stringOptions?: {
        [key: string]: number;
    };
}
export declare type Properties = {
    [key: string]: Schema;
};
export declare type ValueTypes = {
    [key: string]: ValueTypeStatistics;
};
export interface Schema extends JSONSchema7 {
    source?: Source;
    parser?: ParserInfo;
    properties?: Properties;
    unit?: string;
    recordCount?: number;
    recordsNotPresent?: number;
    recordCountApproximate?: boolean;
    byteCount?: number;
    byteCountApproximate?: boolean;
    valueTypes?: ValueTypes;
    sampleRecords?: {
        [key: string]: unknown;
    }[];
}
export interface PackageFile {
    packageSlug: string;
    displayName: string;
    description: string;
    schemas: Schema[];
    version: string;
    generatedBy: string;
    updatedDate: Date;
    readmeFile?: string;
    readmeMarkdown?: string;
    licenseFile?: string;
    licenseMarkdown?: string;
    website?: string;
    contactEmail?: string;
    registries?: RegistryReference[];
}
export * from "./PackageUtil";
export * from "./CollectionUtil";
